==> faxtomail-ui-swing-1.0-sources.jar: com/franciaflex/faxtomail/ui/swing/actions/SaveDemandeFromListAction.java <==
package com.franciaflex.faxtomail.ui.swing.actions;

/*
 * #%L
 * FaxToMail :: UI
 * $Id: SaveDemandeFromListAction.java 660 2014-10-02 11:30:33Z kmorin $
 * $HeadURL: http://svn.codelutin.com/faxtomail/tags/faxtomail-1.0/faxtomail-ui-swing/src/main/java/com/franciaflex/faxtomail/ui/swing/actions/SaveDemandeFromListAction.java $
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.franciaflex.faxtomail.persistence.entities.Email;
import com.franciaflex.faxtomail.persistence.entities.FaxToMailUser;
import com.franciaflex.faxtomail.services.FaxToMailServiceContext;
import com.franciaflex.faxtomail.services.service.EmailService;
import com.franciaflex.faxtomail.ui.swing.FaxToMailUIContext;
import com.franciaflex.faxtomail.ui.swing.content.demande.DemandeListUI;
import com.franciaflex.faxtomail.ui.swing.content.demande.DemandeListUIHandler;
import com.franciaflex.faxtomail.ui.swing.content.demande.DemandeListUIModel;
import com.franciaflex.faxtomail.ui.swing.content.demande.DemandeUIModel;

/**
 * @author Kevin Morin (Code Lutin)
 *
 */
public class SaveDemandeFromListAction extends AbstractFaxToMailAction<DemandeListUIModel, DemandeListUI, DemandeListUIHandler> {

    protected String[] modifiedProperties;

    public SaveDemandeFromListAction(DemandeListUIHandler handler) {
        super(handler, false);
    }

    public void setModifiedProperties(String... properties) {
        modifiedProperties = properties;
    }

    @Override
    public void doAction() throws Exception {
        FaxToMailUIContext context = getContext();

        FaxToMailServiceContext serviceContext = context.newServiceContext();
        EmailService emailService = serviceContext.getEmailService();

        for (DemandeUIModel model : getModel().getSelectedEmails()) {

            String topiaId = model.getTopiaId();
            Email persistedEmail = emailService.getFullEmailById(topiaId);

            FaxToMailUser currentUser = context.getCurrentUser();
            Email email = model.toEntity(persistedEmail);

            email = emailService.saveEmail(email, currentUser, modifiedProperties);
            model.fromEntity(email);
        }
    }
}

==> faxtomail-ui-swing-1.1.3-sources.jar: com/franciaflex/faxtomail/ui/swing/actions/SaveDemandeFromListAction.java <==
package com.franciaflex.faxtomail.ui.swing.actions;

/*
 * #%L
 * FaxToMail :: UI
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.franciaflex.faxtomail.persistence.entities.Email;
import com.franciaflex.faxtomail.persistence.entities.FaxToMailUser;
import com.franciaflex.faxtomail.services.FaxToMailServiceContext;
import com.franciaflex.faxtomail.services.service.EmailService;
import com.franciaflex.faxtomail.ui.swing.FaxToMailUIContext;
import com.franciaflex.faxtomail.ui.swing.content.demande.DemandeListUI;
import com.franciaflex.faxtomail.ui.swing.content.demande.DemandeListUIHandler;
import com.franciaflex.faxtomail.ui.swing.content.demande.DemandeListUIModel;
import com.franciaflex.faxtomail.ui.swing.content.demande.DemandeUIModel;

/**
 * @author Kevin Morin (Code Lutin)
 *
 */
public class SaveDemandeFromListAction extends AbstractFaxToMailAction<DemandeListUIModel, DemandeListUI, DemandeListUIHandler> {

    protected String[] modifiedProperties;

    public SaveDemandeFromListAction(DemandeListUIHandler handler) {
        super(handler, false);
    }

    public void setModifiedProperties(String... properties) {
        modifiedProperties = properties;
    }

    @Override
    public void doAction() throws Exception {
        FaxToMailUIContext context = getContext();

        FaxToMailServiceContext serviceContext = context.newServiceContext();
        EmailService emailService = serviceContext.getEmailService();

        for (DemandeUIModel model : getModel().getSelectedEmails()) {

            String topiaId = model.getTopiaId();
            Email persistedEmail = emailService.getFullEmailById(topiaId);

            FaxToMailUser currentUser = context.getCurrentUser();
            Email email = model.toEntity(persistedEmail);

            email = emailService.saveEmail(email, currentUser, modifiedProperties);
            model.fromEntity(email);
        }
    }
}
